﻿Imports System.Globalization
Imports System.Threading
Imports ThinkGeo.MapSuite.Drawing
Imports ThinkGeo.MapSuite.Layers
Imports ThinkGeo.MapSuite.Serialize
Imports ThinkGeo.MapSuite.Shapes
Imports ThinkGeo.MapSuite.Styles
Imports ThinkGeo.MapSuite.WinForms

Public Class Form1
  Private Sub Form1_Load(sender As Object, e As EventArgs) Handles Me.Load

    LoadLayer()
    Text = "Current culture = " + Globalization.CultureInfo.CurrentCulture.DisplayName
  End Sub
  Private Sub LoadLayer()
    Dim sPath As String = "..\..\Data\LinesSubset.shp"
    Dim oShapefile As New ShapeFileFeatureLayer(sPath, GeoFileReadWriteMode.Read)
    oShapefile.Open()

    Dim oMapExtent = oShapefile.GetBoundingBox
    oMapExtent.ScaleDown(90)

    oShapefile.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColors.Blue, 2, True)
    oShapefile.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20

    Dim oLayerOverlay As New LayerOverlay
    oLayerOverlay.Layers.Add(oShapefile)

    WinformsMap1.MaximumScale = Double.MaxValue
    WinformsMap1.MapUnit = ThinkGeo.MapSuite.GeographyUnit.DecimalDegree
    WinformsMap1.CurrentExtent = oMapExtent
    WinformsMap1.Overlays.Add(oLayerOverlay)

    WinformsMap1.Refresh()



  End Sub
  Private Sub TestSerialization(oMap As WinformsMap)
    Dim oMapProps As New MapProperties

    With oMapProps
      .ThinkGeoVersion = New Version("10.0")
      .BoundingBox = oMap.CurrentExtent
      .MapUnit = oMap.MapUnit
      .NumberOfLayers = 1
      .Name = oMap.Name
      .BackgroundColor = CType(oMap.BackgroundOverlay.BackgroundBrush, GeoSolidBrush).Color
    End With

    Dim sSavePath As String = "..\..\Data\MapProps.xml"
    Dim oSerializer As New GeoSerializer()
    oSerializer.Serialize(oMapProps, sSavePath)


  End Sub
  Private Sub TestDeserialization()
    Dim oMapProps As MapProperties


    Dim sSavePath As String = "..\..\Data\MapProps.xml"
    Dim oSerializer As New GeoSerializer()
    oMapProps = oSerializer.Deserialize(sSavePath, GeoFileReadWriteMode.Read)

    Dim dScale As Double = ExtentHelper.GetScale(oMapProps.BoundingBox, WinformsMap1.Width, WinformsMap1.MapUnit)
    WinformsMap1.CurrentScale = dScale
    WinformsMap1.Refresh()
  End Sub

  Private Sub Button1_Click(sender As Object, e As EventArgs) Handles Button1.Click
    TestSerialization(WinformsMap1)
  End Sub

  Private Sub Button2_Click(sender As Object, e As EventArgs) Handles Button2.Click
    TestDeserialization()
  End Sub
  Private Sub SetCurrentCulture(sCurrentCulture As String)

    If Not sCurrentCulture = String.Empty Then
      Try
        Thread.CurrentThread.CurrentUICulture = New CultureInfo(sCurrentCulture)
        Thread.CurrentThread.CurrentCulture = New CultureInfo(sCurrentCulture)
      Catch ex As Exception
        Thread.CurrentThread.CurrentUICulture = CultureInfo.InvariantCulture
        Thread.CurrentThread.CurrentCulture = CultureInfo.InvariantCulture
      End Try
    End If
    Text = "Current culture = " + Globalization.CultureInfo.CurrentCulture.DisplayName
  End Sub

  Private Sub rbEnglish_CheckedChanged(sender As Object, e As EventArgs) Handles rbEnglish.CheckedChanged, rbPortuguese.CheckedChanged
    Dim sCurrentCulture As String
    If rbPortuguese.Checked Then
      sCurrentCulture = "pt-BR"
    Else
      sCurrentCulture = "en-US"
    End If
    SetCurrentCulture(sCurrentCulture)
  End Sub
End Class
